pub struct PatternsEngine { /* private fields */ }Implementations
Sourceimpl PatternsEngine
impl PatternsEngine
Sourcepub fn with_config(config: &Config) -> Result<Self>
pub fn with_config(config: &Config) -> Result<Self>
Sourcepub fn find_history_commands_from_shell_list(
&self,
shells_context: &Vec<ShellContext>,
) -> Result<ShellCommands>
pub fn find_history_commands_from_shell_list( &self, shells_context: &Vec<ShellContext>, ) -> Result<ShellCommands>
Search sensitive command patterns from the given shell list
Errors
Will return Err when has an error when find sensitive patterns in a
specific shell
Sourcepub fn find_history_commands(
&self,
state_context: &ShellContext,
) -> Result<Vec<Command>>
pub fn find_history_commands( &self, state_context: &ShellContext, ) -> Result<Vec<Command>>